@@ -1,4 +1,4 @@
-"""
+'''
 # aws-kinesisstreams-kinesisfirehose-s3 module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -105,7 +105,7 @@ Out of the box implementation of the Construct without any override will set the
 
 
 © Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -145,7 +145,7 @@ class KinesisStreamsToKinesisFirehoseToS3(
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
-        """
+        '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
@@ -159,7 +159,7 @@ class KinesisStreamsToKinesisFirehoseToS3(
         :access: public
         :since: 1.68.0
         :summary: Constructs a new instance of the KinesisStreamsToKinesisFirehoseToS3 class.
-        """
+        '''
         props = KinesisStreamsToKinesisFirehoseToS3Props(
             bucket_props=bucket_props,
             create_cloud_watch_alarms=create_cloud_watch_alarms,
@@ -235,7 +235,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
-        """The properties for the KinesisStreamsToKinesisFirehoseToS3 class.
+        '''The properties for the KinesisStreamsToKinesisFirehoseToS3 class.
 
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param create_cloud_watch_alarms: Whether to create recommended CloudWatch alarms. Default: - Alarms are created
@@ -244,7 +244,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :param kinesis_firehose_props: Optional user provided props to override the default props. Default: - Default props are used
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
-        """
+        '''
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(kinesis_stream_props, dict):
@@ -269,64 +269,64 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
-        """User provided props to override the default props for the S3 Bucket.
+        '''User provided props to override the default props for the S3 Bucket.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("bucket_props")
         return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
 
     @builtins.property
     def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
-        """Whether to create recommended CloudWatch alarms.
+        '''Whether to create recommended CloudWatch alarms.
 
         :default: - Alarms are created
-        """
+        '''
         result = self._values.get("create_cloud_watch_alarms")
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
-        """Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
+        '''Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_bucket_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
 
     @builtins.property
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
-        """Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
+        '''Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_stream_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
 
     @builtins.property
     def kinesis_firehose_props(self) -> typing.Any:
-        """Optional user provided props to override the default props.
+        '''Optional user provided props to override the default props.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("kinesis_firehose_props")
         return typing.cast(typing.Any, result)
 
     @builtins.property
     def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
-        """Optional user-provided props to override the default props for the Kinesis stream.
+        '''Optional user-provided props to override the default props for the Kinesis stream.
 
         :default: - Default props are used.
-        """
+        '''
         result = self._values.get("kinesis_stream_props")
         return typing.cast(typing.Optional[aws_cdk.aws_kinesis.StreamProps], result)
 
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
-        """User provided props to override the default props for the CloudWatchLogs LogGroup.
+        '''User provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("log_group_props")
         return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
 
